AuthTokenStorage class

Stores and retrieves access/refresh tokens using local storage.

Implemented types

Constructors

AuthTokenStorage(ILocalStorage _storage)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearTokens() Future<bool>
override
getTokenPair() Future<TokenPair?>
override
hasToken() Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveTokenPair(TokenPair tokenPair) Future<bool>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited