BaseListCubit<T> class abstract

Base cubit for fetching, displaying, and manipulating a list of items.

Constructors

BaseListCubit()

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
Whether the bloc is closed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state BaseListState<T>
The current state.
no setterinherited
stream Stream<BaseListState<T>>
The current stream of states.
no setterinherited

Methods

addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
close() Future<void>
Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
inherited
createLoadedState(List<T> items) ListLoaded<T>
emit(BaseListState<T> state) → void
Updates the state to the provided state. emit does nothing if the state being emitted is equal to the current state.
inherited
fetchItems() Future<List<T>>
loadItems() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(Change<BaseListState<T>> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
recoverFromError() → void
refresh() Future<void>
removeItem(bool test(T item)) → void
toString() String
A string representation of this object.
inherited
updateItem(bool test(T item), T updatedItem) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited