BaseOperationCubit<TResult, Id> class
abstract
Base cubit for single async operations (create, update, delete, toggle, etc.).
class DeleteItemCubit extends BaseOperationCubit<void, int> {
final ItemRepository _repo;
DeleteItemCubit(this._repo);
Future<void> delete(int id) => execute(
targetId: id,
operation: () => _repo.delete(id),
);
}
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isClosed → bool
-
Whether the bloc is closed.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
→ BaseOperationState<
Id> -
The current state.
no setterinherited
-
stream
→ Stream<
BaseOperationState< Id> > -
The current stream of states.
no setterinherited
Methods
-
addError(
Object error, [StackTrace? stackTrace]) → void -
Reports an
errorwhich triggersonErrorwith an optional StackTrace.inherited -
close(
) → Future< void> -
Closes the instance.
This method should be called when the instance is no longer needed.
Once
closeis called, the instance can no longer be used.inherited -
emit(
BaseOperationState< Id> state) → void -
Updates the
stateto the providedstate.emitdoes nothing if thestatebeing emitted is equal to the currentstate.inherited -
execute(
{required Future< TResult> operation(), Id? targetId}) → Future<void> -
Runs
operationwith automatic loading, success, and error state handling. Ignores the call if an operation is already in progress. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onChange(
Change< BaseOperationState< change) → voidId> > -
Called whenever a
changeoccurs with the givenchange. Achangeoccurs when a newstateis emitted.onChangeis called before thestateof thecubitis updated.onChangeis a great spot to add logging/analytics for a specificcubit.inherited -
onError(
Object error, StackTrace stackTrace) → void -
Called whenever an
erroroccurs and notifiesBlocObserver.onError.inherited -
reset(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited