components/bottom_sheet_selector/bottom_sheet_selector_container library

Classes

BottomSheetSelectorContainer<T>
Widget that shows a bottom sheet for item selection and renders the appropriate child based on whether an item is selected.