ICache class abstract

Interface for an in-memory cache supporting typed storage, TTL, and removal by key, prefix, or CacheType.

Implementers

Constructors

ICache()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
get<T>(String key) → T?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) → void
removeAllType(CacheType type) → void
removeByPrefix(String prefix) → void
set<T>(String key, T data, {CacheType type = CacheType.global, Duration? ttl}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited