ReadOnlyCache class

A cache wrapper that delegates reads to _delegate but silently ignores all write and removal operations.

Implemented types

Constructors

ReadOnlyCache(ICache _delegate)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
override
get<T>(String key) → T?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) → void
override
removeAllType(CacheType type) → void
override
removeByPrefix(String prefix) → void
override
set<T>(String key, T data, {CacheType type = CacheType.global, Duration? ttl}) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited