CacheData<T> class

A typed cache entry that holds data along with its CacheType, creation timestamp, and optional TTL for expiration.

Constructors

CacheData(CacheType type, T data, {Duration? ttl})

Properties

createdAt DateTime
final
data → T
final
hashCode int
The hash code for this object.
no setterinherited
isExpired bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ttl Duration?
final
type CacheType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited