ApiRequestLogData class

Inheritance

Constructors

ApiRequestLogData(Type type, String endpoint)
const

Properties

endpoint String
final
hashCode int
The hash code for this object.
no setterinherited
level LogLevel
no setteroverride
message String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeAsString String
no setterinherited
timestamp int
no setterinherited
type Type
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited