LogData class abstract

Base class for structured log entries carrying a message and LogLevel.

Implementers

Constructors

LogData()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
level LogLevel
no setter
message String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeAsString String
no setter
timestamp int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited