VarInfoLogData class

Inheritance

Constructors

VarInfoLogData(Map<String, dynamic> varMap, {String? prefix, String? suffix})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
level LogLevel
no setteroverride
message String
no setteroverride
prefix String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffix String?
final
timeAsString String
no setterinherited
timestamp int
no setterinherited
varMap Map<String, dynamic>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited