NotifierService class

Broadcast-based implementation of INotifierService using a StreamController.

Implemented types

Constructors

NotifierService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<NotifierData>
no setteroverride

Methods

dispose() → void
override
listen(String key) Stream<NotifierData>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify<T>({required String key, T? data, Type? source}) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited