NotifierData<T> class

Payload for a notification event, identified by key with optional typed data and source.

Constructors

NotifierData(String key, T? data, [Type? source])
const

Properties

data → T?
final
hashCode int
The hash code for this object.
no setterinherited
key String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source Type?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited