QueryCommandBuilder class
Builds a raw SELECT * SQL command with query clauses from an IQueryBuilder.
- Inheritance
-
- Object
- IDbRawCommandBuilder
- QueryCommandBuilder
Constructors
- QueryCommandBuilder(IDatabaseTable table, IQueryBuilder builder)
-
const
Properties
- builder → IQueryBuilder
-
final
- command → String
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- table → IDatabaseTable
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited