QueryBuilder class

Builds SQL WHERE and LIMIT clauses from optional filter arguments and a row limit.

Inheritance

Constructors

QueryBuilder({int? amount, List<String>? whereArgs})
const

Properties

amount int?
final
hashCode int
The hash code for this object.
no setterinherited
query String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
whereArgs List<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited