IDbManager class abstract

Abstract interface for managing SQLite database operations including CRUD, table creation, and lifecycle management.

Implementers

Constructors

IDbManager({required String dbName, required int dbVersion})

Properties

dbName String
final
dbPath Future<String>
no setter
dbVersion int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createTable(IDatabaseTable table) Future<void>
delete(IDatabaseTable table, IDbDeleteDataMapper mapper) Future<void>
deleteAll(IDatabaseTable table) Future<void>
deleteDb() Future<void>
dispose() Future<void>
insert(IDatabaseTable table, IDbInsertDataMapper mapper) Future<void>
insertRaw(IDatabaseTable table, IDbInsertDataRawMapper mapper) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(IDatabaseTable table) Future<List<Map<String, Object?>>>
queryRaw(IDatabaseTable table, IQueryBuilder queryBuilder) Future<List<Map<String, Object?>>>
toString() String
A string representation of this object.
inherited
update(IDatabaseTable table, IDbUpdateDataMapper mapper) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

insertStream StreamController<IDbDataMapper>
final