IDbUpdateDataMapper class abstract

Mapper that provides a column-value map and row index for database updates.

Inheritance

Constructors

IDbUpdateDataMapper(int index)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
final
key String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Map<String, dynamic>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited