IFileController class abstract

Interface for file controllers that handle creating, loading, and saving files.

Implementers

Constructors

IFileController()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createFile(IPathProvider pathProvider) Future<File>
load(String path, {bool fromAssets = true}) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(IPathProvider pathProvider, IFileConverter data) Future<void>
saveWithFile(File file, IFileConverter data) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited