JsonFileController class

File controller for reading and writing JSON files, supporting both asset and filesystem sources.

Inheritance

Constructors

JsonFileController()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createFile(IPathProvider pathProvider) Future<File>
override
load(String path, {bool fromAssets = true}) Future
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(IPathProvider pathProvider, IFileConverter data) Future<void>
override
saveWithFile(File file, IFileConverter data) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited