DownloadPathProvider class final

Resolves file paths within the platform's downloads directory.

Inheritance

Constructors

DownloadPathProvider(String fileName)
const

Properties

fileName String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
path Future<String>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited