FirebaseAnalyticsEvent class abstract

Represents a named Firebase Analytics event with optional parameters.

Constructors

FirebaseAnalyticsEvent({Map<String, Object>? params})

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
no setter
params Map<String, Object>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addData(AnalyticsData data) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited