UserProperty class abstract
Represents a Firebase Analytics user property as a key-value pair.
Constructors
- UserProperty(String key, String value)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited