IFirebaseForegroundNotificationPresentationConfig class abstract
Configuration for how foreground notifications are presented (alert, badge, sound).
Constructors
- IFirebaseForegroundNotificationPresentationConfig({required bool alert, required bool badge, required bool sound})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited