ILocationService class abstract

Interface for obtaining and caching device location with configurable TTL.

Implementers

Constructors

ILocationService({required Duration positionCacheDuration})

Properties

cachedPosition ↔ Position?
getter/setter pair
cachedPositionDate DateTime?
getter/setter pair
cachedPositionStream Stream<Position>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
newPosition Future<Position?>
no setter
position Future<Position?>
no setter
positionCacheDuration Duration
final
positionStream Future<Stream<Position>?>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

init() Future<void>
initPositionStream() Future<Stream<Position>?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
routeToSettings() Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited