ICustomNotificationContent class abstract

Base notification content built from a remote notification and channel config.

Constructors

ICustomNotificationContent(PushNotificationChannelConfig channelConfig, RemoteNotification notification, {NotificationLayout layout = NotificationLayout.Default, String? imageUrl, Map<String, String?>? payload})

Properties

actionType ↔ ActionType?
Returns the action type of the notification.
getter/setter pairinherited
autoCancel bool?
no setterinherited
autoDismissable bool?
no setterinherited
autoDismissible bool?
Returns whether the notification is auto-dismissible.
no setterinherited
backgroundColor Color?
Returns the background color of the notification.
no setterinherited
badge int?
Returns the badge number for the notification.
no setterinherited
bigPicture String?
Returns the big picture of the notification.
no setterinherited
bigPictureImage ImageProvider<Object>?
no setterinherited
bigPicturePath String?
no setterinherited
body String?
Returns the body text of the notification.
no setterinherited
bodyLockArgs List<String>?
Returns the args used to translate the notification body.
no setterinherited
bodyLockKey String?
Returns the body key used to translate the notification.
no setterinherited
bodyWithoutHtml String?
no setterinherited
category → NotificationCategory?
Returns the category of the notification.
no setterinherited
channelKey String?
Returns the channel key of the notification.
no setterinherited
chronometer Duration?
Returns the chronometer duration for the notification.
no setterinherited
color Color?
Returns the color of the notification.
no setterinherited
createdDate DateTime?
getter/setter pairinherited
createdLifeCycle ↔ NotificationLifeCycle?
getter/setter pairinherited
createdSource ↔ NotificationSource?
getter/setter pairinherited
criticalAlert bool?
Returns whether the notification is a critical alert.
no setterinherited
customSound String?
Returns the custom sound of the notification.
no setterinherited
displayedDate DateTime?
Returns the date and time when the notification was displayed.
getter/setter pairinherited
displayedLifeCycle ↔ NotificationLifeCycle?
getter/setter pairinherited
displayOnBackground bool?
Indicates whether the notification is displayed when the app is in the background.
no setterinherited
displayOnForeground bool?
Indicates whether the notification is displayed when the app is in the foreground.
no setterinherited
duration Duration?
Returns the play media duration (media player).
no setterinherited
fullScreenIntent bool?
Returns whether the notification should use a full screen intent.
no setterinherited
groupKey String?
Returns the group key of the notification.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hideLargeIconOnExpand bool?
Returns whether to hide the large icon when the notification is expanded.
no setterinherited
icon String?
Returns the icon of the notification.
no setterinherited
id int?
Returns the id of the notification.
no setterinherited
largeIcon String?
Returns the large icon of the notification.
no setterinherited
largeIconImage ImageProvider<Object>?
no setterinherited
largeIconPath String?
no setterinherited
locked bool?
Indicates whether the notification is locked.
no setterinherited
notificationLayout → NotificationLayout?
Returns the layout type of the notification.
no setterinherited
payload Map<String, String?>?
Returns the custom payload of the notification.
no setterinherited
playbackSpeed double?
Returns the playback speed for notification (media player).
no setterinherited
playState → NotificationPlayState?
Returns the play state of the notification (media player).
no setterinherited
privacy ↔ NotificationPrivacy?
Returns the privacy setting of the notification.
getter/setter pairinherited
progress double?
Returns the progress value of the notification, if set.
no setterinherited
roundedBigPicture bool?
Returns whether the big picture should be rounded.
no setterinherited
roundedLargeIcon bool?
Returns whether the large icon should be rounded.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showWhen bool?
Returns whether the notification should show a timestamp.
no setterinherited
summary String?
Returns the summary of the notification.
no setterinherited
ticker String?
Returns the ticker text of the notification.
no setterinherited
timeoutAfter Duration?
Returns the duration after which the notification should be timed out.
no setterinherited
title String?
Returns the title of the notification.
no setterinherited
titleLockArgs List<String>?
Returns the args used to translate the notification title.
no setterinherited
titleLockKey String?
Returns the title key used to translate the notification.
no setterinherited
titleWithoutHtml String?
no setterinherited
wakeUpScreen bool?
Returns whether the notification should wake up the screen.
no setterinherited

Methods

fromMap(Map<String, dynamic> mapData) → NotificationContent?
Creates a NotificationContent instance from a map of data.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processRetroCompatibility(Map<String, dynamic> dataMap) Map<String, dynamic>
inherited
toMap() Map<String, dynamic>
Converts the NotificationContent instance to a map.
inherited
toString() String
Returns a string representation of the NotificationContent instance.
inherited
validate() → void
Validates
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited