displayOnForeground property
Indicates whether the notification is displayed when the app is in the foreground.
Implementation
bool? get displayOnForeground {
return _displayOnForeground;
}
Indicates whether the notification is displayed when the app is in the foreground.
bool? get displayOnForeground {
return _displayOnForeground;
}