EnvironmentInterpreter class

Utility for parsing environment variable strings into typed values (booleans, enums).

Constructors

EnvironmentInterpreter()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isTrue(String? value) bool
mapImportanceToEnum(String? value) → NotificationImportance
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited