DateTimeFormatter class

Formats DateTime values into locale-aware date, time, and duration strings.

Constructors

DateTimeFormatter()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dateFormatter(DateTime dateTime, BuildContext context) String
formatSeconds(int totalSeconds, String minShort) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
timeFormatter(DateTime dateTime, BuildContext context) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited