MapLauncher class

Launches Apple Maps or Google Maps for a given coordinate, with fallback error handling.

Mixed-in types

Constructors

MapLauncher({Uri appleMapsUrlBuilder(double lat, double lng) = _defaultAppleMapsUrl, Uri googleMapsUrlBuilder(double lat, double lng) = _defaultGoogleMapsUrl, String errorMessage = 'Could not open maps application'})
const

Properties

appleMapsUrlBuilder Uri Function(double lat, double lng)
final
errorMessage String
final
googleMapsUrlBuilder Uri Function(double lat, double lng)
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

displayErrorSnack({required BuildContext context, required String message}) → void
inherited
displaySnack({required BuildContext context, required String message}) → void
inherited
displaySuccessSnack({required BuildContext context, required String message}) → void
inherited
displayWarningSnack({required BuildContext context, required String message}) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open({required BuildContext context, required double latitude, required double longitude}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited