RouteStackItem class
Represents a single entry in the navigation stack with route name and arguments.
Constructors
- RouteStackItem({required String? name, required Object? args})
-
const
- RouteStackItem.fromRoute(Route route)
-
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited