RoutingBase class abstract
Base class for app routing, providing iOS, Material, and opacity page transitions.
Constructors
- RoutingBase()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateRoute(
RouteSettings settings) → Route -
iosRouting(
Widget child, RouteSettings settings, {bool isFullScreen = false}) → Route -
materialRouting(
Widget child, RouteSettings settings) → Route -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
opacityRoute(
Widget page, RouteSettings settings) → PageRoute -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited