ValidatorMessages class

Customizable validation error messages used by Validators.

Constructors

ValidatorMessages({String required = 'This field is required', String invalidEmail = 'Enter a valid email', String invalidPhone = 'Enter a valid phone number', String invalidNumber = 'Enter a valid number', String mismatch = 'Values do not match', String minLength(int min) = _defaultMinLength, String passwordMinLength(int min) = _defaultPasswordMinLength})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
invalidEmail String
final
invalidNumber String
final
invalidPhone String
final
minLength String Function(int min)
final
mismatch String
final
passwordMinLength String Function(int min)
final
required String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited