ErrorLogData class
Constructors
- ErrorLogData(String className, String methodName, Type errorType, {String? message})
-
const
Properties
- className → String
-
final
- errorType → Type
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- level → LogLevel
-
no setteroverride
- message → String
-
no setteroverride
- methodName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeAsString → String
-
no setterinherited
- timestamp → int
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited