INotifierService class abstract
Interface for a lightweight pub/sub notification service using streams.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
NotifierData> -
no setter
Methods
-
dispose(
) → void -
listen(
String key) → Stream< NotifierData> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notify<
T> ({required String key, T? data, Type? source}) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited