InsertCommandBuilder class
Builds a raw INSERT INTO SQL command using a table definition and a raw mapper.
- Inheritance
-
- Object
- IDbRawCommandBuilder
- InsertCommandBuilder
Constructors
- InsertCommandBuilder(IDatabaseTable table, IDbInsertDataRawMapper mapper)
-
const
Properties
- command → String
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- mapper → IDbInsertDataRawMapper
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- table → IDatabaseTable
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited