QueryBuilder class
Builds SQL WHERE and LIMIT clauses from optional filter arguments and a row limit.
- Inheritance
-
- Object
- IQueryBuilder
- QueryBuilder
Constructors
-
QueryBuilder({int? amount, List<
String> ? whereArgs}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited