IDbDeleteDataMapper class abstract
Mapper that identifies a database row by index for deletion.
- Inheritance
-
- Object
- IDbDataMapper
- IDbDeleteDataMapper
Constructors
- IDbDeleteDataMapper(int index)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited