IDatabaseTable class abstract
Describes a database table by its name and column definitions, and provides formatted column identifiers for SQL statements.
Constructors
- IDatabaseTable(String name)
-
const
Properties
- colIdentifier → String
-
no setter
- colIdentifierForInsert → String
-
no setter
-
columns
→ Map<
String, String> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited