BaseNetworkConfig class
Holds base network configuration (URL, timeouts) and creates a Dio client from it.
Constructors
- BaseNetworkConfig({required String baseUrl, Duration connectTimeout = const Duration(seconds: 30), Duration receiveTimeout = const Duration(seconds: 30), Duration sendTimeout = const Duration(seconds: 30)})
-
const
Properties
- baseUrl → String
-
final
- connectTimeout → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- receiveTimeout → Duration
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendTimeout → Duration
-
final
Methods
-
createDio(
) → Dio -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited