IRemoteDatasource class abstract
Base class for remote data sources that execute plain or
authenticated HTTP requests via Dio.
Constructors
- IRemoteDatasource(IAuthTokenStorage authTokenStorage, Dio dio)
-
const
Properties
- authTokenStorage → IAuthTokenStorage
-
final
- dio → Dio
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createAuthOptions(
String? token) → Options -
doAuthorisedRequest<
T> (Future< T> request(String?)) → Future<T> -
doRequest<
T> (Future< T> request()) → Future<T> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited