AuthInterceptor class
Attaches JWT access tokens to outgoing requests and handles token refresh.
- Proactively refreshes tokens that are about to expire (within
_refreshThreshold). - On 401 responses, attempts a single token refresh and retries the request via
_retryDio. - Concurrent requests during a refresh are queued and resolved with the new token.
- Paths listed in
_skipAuthPathsbypass authentication entirely.
Compatible with InterceptorPipeline — can be used standalone or as part of a pipeline.
Constructors
-
AuthInterceptor({required IAuthTokenStorage authTokenStorage, required TokenRefreshCallback onTokenRefresh, required AuthFailureCallback onAuthFailure, required Dio retryDio, List<
String> skipAuthPaths = const []})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
DioException err, ErrorInterceptorHandler handler) → Future< void> - Called when an exception was occurred during the request.
-
onRequest(
RequestOptions options, RequestInterceptorHandler handler) → Future< void> - Called when the request is about to be sent.
-
onResponse(
Response response, ResponseInterceptorHandler handler) → void -
Called when the response is about to be resolved.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited