FirebaseAnalyticsEvent class abstract
Represents a named Firebase Analytics event with optional parameters.
Constructors
-
FirebaseAnalyticsEvent({Map<
String, Object> ? params})
Properties
Methods
-
addData(
AnalyticsData data) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited