IFirebaseAnalyticsService class abstract
Interface for logging Firebase Analytics events and setting user properties.
Constructors
Properties
- analyticsInstance → FirebaseAnalytics
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- observer → FirebaseAnalyticsObserver
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
init(
) → void -
logEvent(
FirebaseAnalyticsEvent event) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setUserProperty(
UserProperty property) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited