IFirebaseService class abstract
Aggregates Firebase sub-services (analytics, messaging, realtime DB) and handles initialization.
Constructors
- IFirebaseService({IFirebaseAnalyticsService? analytics, IFirebaseMessagingService? messaging, IFirebaseRealtimeDatabaseService? realTimeDb})
-
const
Properties
- analytics → IFirebaseAnalyticsService?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- messaging → IFirebaseMessagingService?
-
final
- realTimeDb → IFirebaseRealtimeDatabaseService?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
initServices(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited