IFirebaseRealtimeDatabaseService class abstract
Interface for subscribing to Firebase Realtime Database paths with event handlers.
Constructors
- IFirebaseRealtimeDatabaseService()
-
const
Properties
- db → FirebaseDatabase
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
init(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
set(
IFirebaseDbReferencePath path, IFirebaseDatabaseEventHandler eventHandler) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited