LocationService class
Concrete location service using Geolocator with position caching and streaming.
- Inheritance
-
- Object
- ILocationService
- LocationService
Constructors
- LocationService({required Duration positionCacheDuration})
Properties
- cachedPosition ↔ Position?
-
getter/setter pairinherited
- cachedPositionDate ↔ DateTime?
-
getter/setter pairinherited
-
cachedPositionStream
↔ Stream<
Position> ? -
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
newPosition
→ Future<
Position> -
no setteroverride
-
position
→ Future<
Position?> -
no setteroverride
- positionCacheDuration → Duration
-
finalinherited
-
positionStream
→ Future<
Stream< Position> ?> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
init(
) → Future< void> -
override
-
initPositionStream(
) → Future< Stream< Position> ?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
routeToSettings(
) → Future< bool> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited