PushNotificationChannelConfig class
Configuration for an Awesome Notifications channel, constructable from environment variables.
Constructors
- PushNotificationChannelConfig({required String channelKey, required String channelName, required String channelDescription, bool criticalAlerts = true, bool onlyAlertOnce = true, bool playSound = true, bool enableVibration = true, bool locked = true, NotificationImportance importance = NotificationImportance.Max})
-
const
-
PushNotificationChannelConfig.fromEnv(String prefix, Map<
String, String> env) -
factory
Properties
- channel → NotificationChannel
-
no setter
- channelDescription → String
-
final
- channelKey → String
-
final
- channelName → String
-
final
- criticalAlerts → bool
-
final
- enableVibration → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- importance → NotificationImportance
-
final
- locked → bool
-
final
- onlyAlertOnce → bool
-
final
- playSound → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited