IPushNotificationManager class abstract
Manages push notification initialization, channel configuration from env, and local/remote push.
Constructors
- IPushNotificationManager({required INotificationListeners notificationListeners, required String envFilePath, String? iconPath})
Properties
- envFilePath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconPath → String?
-
final
-
notificationChannelConfigs
→ List<
PushNotificationChannelConfig> -
final
- notificationListeners → INotificationListeners
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
init(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pushLocal(
ICustomRemoteMessage message, {PushNotificationChannelConfig? channelConfig}) → void -
pushRemote(
ICustomRemoteMessage message, {PushNotificationChannelConfig? channelConfig}) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited