ICustomRemoteMessage class abstract
Base class for custom remote messages extending Firebase RemoteMessage.
Constructors
-
ICustomRemoteMessage({required RemoteNotification? notification, Map<
String, dynamic> data = const <String, dynamic>{}}) -
const
Properties
- actionIdentifier → String?
-
The Apple notification action identifier used to open the app.
finalinherited
- category → String?
-
The iOS category this notification is assigned to.
finalinherited
- collapseKey → String?
-
The collapse key a message was sent with. Used to override existing messages with the same key.
finalinherited
- contentAvailable → bool
-
Whether the iOS APNs message was configured as a background update notification.
finalinherited
-
data
→ Map<
String, dynamic> -
Any additional data sent with the message.
finalinherited
- from → String?
-
The topic name or message identifier.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageId → String?
-
A unique ID assigned to every message.
finalinherited
- messageType → String?
-
The message type of the message.
finalinherited
- mutableContent → bool
-
Whether the iOS APNs
mutable-contentproperty on the message was set allowing the app to modify the notification via app extensions.finalinherited - notification → RemoteNotification?
-
Additional Notification data sent with the message.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderId → String?
-
The ID of the upstream sender location.
finalinherited
- sentTime → DateTime?
-
The time the message was sent, represented as a DateTime.
finalinherited
- threadId → String?
-
An iOS app specific identifier used for notification grouping.
finalinherited
- ttl → int?
-
The time to live for the message in seconds.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
Returns the
RemoteMessageas a raw Map.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited