ICustomRemoteNotification class abstract
Base class for custom remote notifications extending Firebase RemoteNotification.
Constructors
- ICustomRemoteNotification({String? title, String? body})
-
const
Properties
- android → AndroidNotification?
-
Android specific notification properties.
finalinherited
- apple → AppleNotification?
-
Apple specific notification properties.
finalinherited
- body → String?
-
The notification body content.
finalinherited
-
bodyLocArgs
→ List<
String> -
Any arguments that should be formatted into the resource specified by bodyLocKey.
finalinherited
- bodyLocKey → String?
-
The native localization key for the notification body content.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
The notification title.
finalinherited
-
titleLocArgs
→ List<
String> -
Any arguments that should be formatted into the resource specified by titleLocKey.
finalinherited
- titleLocKey → String?
-
The native localization key for the notification title.
finalinherited
- web → WebNotification?
-
Web specific notification properties.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
Returns the
RemoteNotificationas a raw Map.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited